@@ -6,6 +6,8 @@ import logging
 import os
 import sys
 from jsonschema.exceptions import ValidationError
+
+from cfnlint import Template
 from cfnlint.rules import RulesCollection
 import cfnlint.config
 import cfnlint.formatters
@@ -36,12 +38,16 @@ class UnexpectedRuleException(CfnLintExitException):
     """When processing a rule fails in an unexpected way"""
 
 
-def run_cli(filename, template, rules, regions, override_spec, mandatory_rules=None):
+def run_cli(filename, template, rules, regions, override_spec, build_graph, mandatory_rules=None):
     """Process args and run"""
 
     if override_spec:
         cfnlint.helpers.override_specs(override_spec)
 
+    if build_graph:
+        template_obj = Template(filename, template, regions)
+        template_obj.build_graph()
+
     return run_checks(filename, template, rules, regions, mandatory_rules)
 
 
