@@ -1,23 +1,11 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import re
 import six
-from cfnlint import CloudFormationLintRule
-from cfnlint import RuleMatch
+from cfnlint.rules import CloudFormationLintRule
+from cfnlint.rules import RuleMatch
 
 
 class Default(CloudFormationLintRule):
@@ -37,7 +25,8 @@ class Default(CloudFormationLintRule):
             if not re.match(allowed_pattern, str(allowed_value)):
                 return([RuleMatch(path, message)])
         except re.error as ex:
-            self.logger.debug('Regex pattern "%s" isn\'t supported by Python: %s', allowed_pattern, ex)
+            self.logger.debug('Regex pattern "%s" isn\'t supported by Python: %s',
+                              allowed_pattern, ex)
 
         return []
 
@@ -82,8 +71,9 @@ class Default(CloudFormationLintRule):
         """
         message = 'Default should have a length above or equal to MinLength'
 
+        value = allowed_value if isinstance(allowed_value, six.string_types) else str(allowed_value)
         if isinstance(min_length, six.integer_types):
-            if len(allowed_value) < min_length:
+            if len(value) < min_length:
                 return([RuleMatch(path, message)])
 
         return []
@@ -94,8 +84,9 @@ class Default(CloudFormationLintRule):
         """
         message = 'Default should have a length below or equal to MaxLength'
 
+        value = allowed_value if isinstance(allowed_value, six.string_types) else str(allowed_value)
         if isinstance(max_length, six.integer_types):
-            if len(allowed_value) > max_length:
+            if len(value) > max_length:
                 return([RuleMatch(path, message)])
 
         return []
