@@ -1,20 +1,10 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import six
+
+from cfnlint.helpers import valid_snapshot_types
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
 
@@ -37,15 +27,6 @@ class DeletionPolicy(CloudFormationLintRule):
             'Snapshot'
         ]
 
-        valid_snapshot_types = [
-            'AWS::EC2::Volume',
-            'AWS::ElastiCache::CacheCluster',
-            'AWS::ElastiCache::ReplicationGroup',
-            'AWS::Neptune::DBCluster',
-            'AWS::RDS::DBCluster',
-            'AWS::RDS::DBInstance',
-            'AWS::Redshift::Cluster'
-        ]
         if not isinstance(key, (six.text_type, six.string_types)):
             message = 'DeletionPolicy values should be of string at {0}'
             matches.append(RuleMatch(path, message.format('/'.join(map(str, path)))))
